# Django Axor Auth

An opinionated Django authentication app that provides a set of views and forms for user authentication.

It is built so you can skip authentication implementation in your Django project and focus on building your business logic.

## Usage

Please visit the [documentation](https://axor.nzran.com) for detailed usage instructions.